@@ -14,7 +14,7 @@ use Socket;
 use Storable;
 use vars qw($VERSION);
 
-$VERSION = '1.16';
+$VERSION = '1.18';
 
 sub spawn {
   my $package = shift;
@@ -741,9 +741,9 @@ sub SMTPD_message {
   my $from = ${ $_[1] };
   my $rcpt = ${ $_[2] };
   my $buf = ${ $_[3] };
-  my $msg_id = Email::MessageID->new;
+  my $msg_id = Email::MessageID->new( host => $self->{hostname} );
   my $uid = $msg_id->user();
-  unshift @{ $buf }, "Message-ID: <$uid\@" . $self->{hostname} . '>' 
+  unshift @{ $buf }, "Message-ID: " . $msg_id->in_brackets()
 	unless grep { /^Message-ID:/i } @{ $buf };
   unshift @{ $buf }, "Received: from Unknown [" . $self->{clients}->{ $id }->{peeraddr} . "] by " . $self->{hostname} . " " . __PACKAGE__ . "-$VERSION with SMTP id $uid; " . strftime("%a, %d %b %Y %H:%M:%S %z", localtime); 
   $self->send_to_client( $id, "250 $uid Message accepted for delivery" );
